@@ -47,7 +47,10 @@ TOOLTIP_OCCUPANCY_COMMON = \
 TOOLTIP_OCCUPANCY_OVERVIEW = \
     "This overall number is the weighted average of all kernels' OCC_K " \
     "using kernel's execution duration as weight. " \
-    "It shows fine-grained low-level GPU utilization."
+    "It shows fine-grained low-level GPU utilization.\n"
+TOOLTIP_TENSOR_CORES = \
+    "Kernel using Tensor Cores:\n" \
+    "Total GPU Time for Tensor Core kernels / Total GPU Time for all kernels.\n"
 TOOLTIP_OCCUPANCY_TABLE = \
     "This \"Mean\" number is the weighted average of all calls' OCC_K of the kernel, " \
     "using each call's execution duration as weight. " \
@@ -57,3 +60,13 @@ TOOLTIP_BLOCKS_PER_SM = \
     "If this number is less than 1, it indicates the GPU multiprocessors are not fully utilized.\n" \
     "\"Mean Blocks per SM\" is the weighted average of all calls of this kernel, " \
     "using each call's execution duration as weight."
+TOOLTIP_OP_TC_ELIGIBLE = \
+    "Whether this operator is eligible to use Tensor Cores."
+TOOLTIP_OP_TC_SELF = \
+    "Time of self-kernels with Tensor Cores / Time of self-kernels."
+TOOLTIP_OP_TC_TOTAL = \
+    "Time of kernels with Tensor Cores / Time of kernels."
+TOOLTIP_KERNEL_USES_TC = \
+    "Whether this kernel uses Tensor Cores."
+TOOLTIP_KERNEL_OP_TC_ELIGIBLE = \
+    "Whether the operator launched this kernel is eligible to use Tensor Cores."
