@@ -4,7 +4,6 @@
 import atexit
 import gzip
 import json
-import multiprocessing as mp
 import os
 import sys
 import tempfile
@@ -44,9 +43,6 @@ class TorchProfilerPlugin(base_plugin.TBPlugin):
           context: A base_plugin.TBContext instance.
         """
         super(TorchProfilerPlugin, self).__init__(context)
-        start_method = os.getenv('TORCH_PROFILER_START_METHOD')
-        if start_method:
-            mp.set_start_method(start_method, force=True)
         self.logdir = io.abspath(context.logdir.rstrip('/'))
 
         self._load_lock = threading.Lock()
@@ -75,8 +71,13 @@ class TorchProfilerPlugin(base_plugin.TBPlugin):
 
     def is_active(self):
         """Returns whether there is relevant data for the plugin to process.
+        If there is no any pending run, hide the plugin
         """
-        return True
+        if self.is_loading:
+            return True
+        else:
+            with self._runs_lock:
+                return bool(self._runs)
 
     def get_plugin_apps(self):
         return {
@@ -94,12 +95,15 @@ class TorchProfilerPlugin(base_plugin.TBPlugin):
             "/operation/stack": self.operation_stack_route,
             "/kernel": self.kernel_pie_route,
             "/kernel/table": self.kernel_table_route,
+            "/kernel/tc_pie": self.kernel_tc_route,
             "/trace": self.trace_route,
             "/distributed/gpuinfo": self.dist_gpu_info_route,
             "/distributed/overlap": self.comm_overlap_route,
             "/distributed/waittime": self.comm_wait_route,
             "/distributed/commops": self.comm_ops_route,
             "/memory": self.memory_route,
+            "/memory_curve": self.memory_curve_route,
+            "/memory_events": self.memory_events_route,
         }
 
     def frontend_metadata(self):
@@ -110,12 +114,9 @@ class TorchProfilerPlugin(base_plugin.TBPlugin):
         with self._runs_lock:
             names = list(self._runs.keys())
 
-        with self._load_lock:
-            loading = bool(self._load_threads)
-
         data = {
             "runs": names,
-            "loading": loading
+            "loading": self.is_loading
         }
         return self.respond_as_json(data)
 
@@ -219,6 +220,12 @@ class TorchProfilerPlugin(base_plugin.TBPlugin):
         else:
             return self.respond_as_json(profile.kernel_op_table)
 
+    @wrappers.Request.application
+    def kernel_tc_route(self, request):
+        profile = self._get_profile_for_request(request)
+
+        return self.respond_as_json(profile.tc_pie)
+
     @wrappers.Request.application
     def trace_route(self, request):
         profile = self._get_profile_for_request(request)
@@ -272,7 +279,36 @@ class TorchProfilerPlugin(base_plugin.TBPlugin):
     @wrappers.Request.application
     def memory_route(self, request):
         profile = self._get_profile_for_request(request)
-        return self.respond_as_json(profile.memory_view)
+        start_ts = request.args.get("start_ts", None)
+        end_ts = request.args.get("end_ts", None)
+        memory_metric = request.args.get("memory_metric", "KB")
+        if start_ts is not None:
+            start_ts = int(start_ts)
+        if end_ts is not None:
+            end_ts = int(end_ts)
+
+        return self.respond_as_json(RunProfile.get_memory_stats(profile, start_ts=start_ts, end_ts=end_ts, memory_metric=memory_metric))
+
+    @wrappers.Request.application
+    def memory_curve_route(self, request):
+        profile = self._get_profile_for_request(request)
+        time_metric = request.args.get("time_metric", "ms")
+        memory_metric = request.args.get("memory_metric", "MB")
+        return self.respond_as_json(RunProfile.get_memory_curve(profile, time_metric=time_metric, memory_metric=memory_metric))
+
+    @wrappers.Request.application
+    def memory_events_route(self, request):
+        profile = self._get_profile_for_request(request)
+        start_ts = request.args.get("start_ts", None)
+        end_ts = request.args.get("end_ts", None)
+        time_metric = request.args.get("time_metric", "ms")
+        memory_metric = request.args.get("memory_metric", "KB")
+        if start_ts is not None:
+            start_ts = int(start_ts)
+        if end_ts is not None:
+            end_ts = int(end_ts)
+
+        return self.respond_as_json(RunProfile.get_memory_events(profile, start_ts, end_ts, time_metric=time_metric, memory_metric=memory_metric))
 
     @wrappers.Request.application
     def static_file_route(self, request):
@@ -301,6 +337,11 @@ class TorchProfilerPlugin(base_plugin.TBPlugin):
         content = json.dumps(obj)
         return werkzeug.Response(content, content_type="application/json", headers=TorchProfilerPlugin.headers)
 
+    @property
+    def is_loading(self):
+        with self._load_lock:
+            return bool(self._load_threads)
+
     def _monitor_runs(self):
         logger.info("Monitor runs begin")
 
@@ -427,7 +468,7 @@ class TorchProfilerPlugin(base_plugin.TBPlugin):
 
     def _check_distributed_profile(self, profile, name):
         if not isinstance(profile, DistributedRunProfile):
-            raise exceptions.BadRequest("Get an unexpected distributed profile type %s for %s/%s" %(type(profile), name))
+            raise exceptions.BadRequest("Get an unexpected distributed profile type %s for %s" %(type(profile), name))
 
     def _validate(self, **kwargs):
         for name,v in kwargs.items():
